@@ -487,7 +487,8 @@ def detect_tests_to_run():
         # TODO: Set BOOST_ROOT in .appveyor.yml
         gathered_tests += [('framework', ['test cases/frameworks/1 boost'], 'BOOST_ROOT' not in os.environ)]
     elif mesonlib.is_osx() or mesonlib.is_cygwin():
-        gathered_tests += [('framework', gather_tests('test cases/frameworks'), True)]
+        # Just do the BOOST test
+        gathered_tests += [('framework', ['test cases/frameworks/1 boost'], False)]
     else:
         gathered_tests += [('framework', gather_tests('test cases/frameworks'), False)]
     return gathered_tests
